==> jc-1.4.0.tar.gz: javax/imageio/stream/FileCacheImageOutputStream.h <==
// public class javax.imageio.stream.FileCacheImageOutputStream

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f95f4a024ec69f9c javax_imageio_stream_FileCacheImageOutputStream
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl
// @dep_class a6cc78290aff4a42 javax_imageio_stream_ImageOutputStreamImpl

// header file dependencies
// @dep_header javax_imageio_stream_ImageOutputStreamImpl

#include "javax/imageio/stream/ImageOutputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_FileCacheImageOutputStream_H_
#define _JC_javax_imageio_stream_FileCacheImageOutputStream_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_refs	_jc_javax_imageio_stream_FileCacheImageOutputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_nonrefs	_jc_javax_imageio_stream_FileCacheImageOutputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_FileCacheImageOutputStream$refs	_jc_javax_imageio_stream_FileCacheImageOutputStream$refs;
typedef struct _jc_javax_imageio_stream_FileCacheImageOutputStream$nonrefs	_jc_javax_imageio_stream_FileCacheImageOutputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object	_jc_javax_imageio_stream_FileCacheImageOutputStream$object;

typedef const struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vmethods	_jc_javax_imageio_stream_FileCacheImageOutputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vtable	_jc_javax_imageio_stream_FileCacheImageOutputStream$vtable;
typedef const struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vtype	_jc_javax_imageio_stream_FileCacheImageOutputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_FileCacheImageOutputStream$method$_init$f10c6af10b72d737(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_java_io_File$object *);

// Virtual methods
extern void _jc_javax_imageio_stream_FileCacheImageOutputStream$method$checkStreamClosed$e73f603b18f58e4c(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
extern void _jc_javax_imageio_stream_FileCacheImageOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
extern jboolean _jc_javax_imageio_stream_FileCacheImageOutputStream$method$isCached$7eabc2d936c77133(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
extern jboolean _jc_javax_imageio_stream_FileCacheImageOutputStream$method$isCachedFile$ed19c4c24a1815db(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
extern jboolean _jc_javax_imageio_stream_FileCacheImageOutputStream$method$isCachedMemory$53b63747781a10df(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
extern jint _jc_javax_imageio_stream_FileCacheImageOutputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
extern jint _jc_javax_imageio_stream_FileCacheImageOutputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_javax_imageio_stream_FileCacheImageOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, jint);
extern void _jc_javax_imageio_stream_FileCacheImageOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$checkStreamClosed$e73f603b18f58e4c;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$isCached$7eabc2d936c77133;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$isCachedFile$ed19c4c24a1815db;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$isCachedMemory$53b63747781a10df;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vmethods {
	void	(*checkStreamClosed$e73f603b18f58e4c)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
	jboolean	(*isCached$7eabc2d936c77133)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
	jboolean	(*isCachedFile$ed19c4c24a1815db)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
	jboolean	(*isCachedMemory$53b63747781a10df)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, jint);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_ImageOutputStreamImpl$vmethods	javax_imageio_stream_ImageOutputStreamImpl;
	_jc_javax_imageio_stream_FileCacheImageOutputStream$vmethods	javax_imageio_stream_FileCacheImageOutputStream;
};

// Vtype
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_FileCacheImageOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_refs {
	struct _jc_java_io_OutputStream$object	*stream;
	struct _jc_java_io_File$object	*cacheDir;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$refs {
    _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_refs	javax_imageio_stream_FileCacheImageOutputStream;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_refs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_nonrefs	javax_imageio_stream_FileCacheImageOutputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object {
	_jc_javax_imageio_stream_FileCacheImageOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_FileCacheImageOutputStream$vtype	*vtype;
	_jc_javax_imageio_stream_FileCacheImageOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_FileCacheImageOutputStream$vtype _jc_javax_imageio_stream_FileCacheImageOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_FileCacheImageOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_FileCacheImageOutputStream$class_object;

#endif	/* _JC_javax_imageio_stream_FileCacheImageOutputStream_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/stream/FileCacheImageOutputStream.h <==
// public class javax.imageio.stream.FileCacheImageOutputStream

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f95f4a024ec69f9c javax_imageio_stream_FileCacheImageOutputStream
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl
// @dep_class a6cc78290aff4a42 javax_imageio_stream_ImageOutputStreamImpl

// header file dependencies
// @dep_header javax_imageio_stream_ImageOutputStreamImpl

#include "javax/imageio/stream/ImageOutputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_FileCacheImageOutputStream_H_
#define _JC_javax_imageio_stream_FileCacheImageOutputStream_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_refs	_jc_javax_imageio_stream_FileCacheImageOutputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_nonrefs	_jc_javax_imageio_stream_FileCacheImageOutputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_FileCacheImageOutputStream$refs	_jc_javax_imageio_stream_FileCacheImageOutputStream$refs;
typedef struct _jc_javax_imageio_stream_FileCacheImageOutputStream$nonrefs	_jc_javax_imageio_stream_FileCacheImageOutputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object	_jc_javax_imageio_stream_FileCacheImageOutputStream$object;

typedef const struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vmethods	_jc_javax_imageio_stream_FileCacheImageOutputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vtable	_jc_javax_imageio_stream_FileCacheImageOutputStream$vtable;
typedef const struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vtype	_jc_javax_imageio_stream_FileCacheImageOutputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_FileCacheImageOutputStream$method$_init$f10c6af10b72d737(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_imageio_stream_FileCacheImageOutputStream$method$checkStreamClosed$e73f603b18f58e4c(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_FileCacheImageOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_FileCacheImageOutputStream$method$isCached$7eabc2d936c77133(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_FileCacheImageOutputStream$method$isCachedFile$ed19c4c24a1815db(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_FileCacheImageOutputStream$method$isCachedMemory$53b63747781a10df(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_FileCacheImageOutputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_FileCacheImageOutputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_FileCacheImageOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_FileCacheImageOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$checkStreamClosed$e73f603b18f58e4c;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$isCached$7eabc2d936c77133;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$isCachedFile$ed19c4c24a1815db;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$isCachedMemory$53b63747781a10df;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vmethods {
	void	(*checkStreamClosed$e73f603b18f58e4c)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*isCached$7eabc2d936c77133)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*isCachedFile$ed19c4c24a1815db)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*isCachedMemory$53b63747781a10df)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_ImageOutputStreamImpl$vmethods	javax_imageio_stream_ImageOutputStreamImpl;
	_jc_javax_imageio_stream_FileCacheImageOutputStream$vmethods	javax_imageio_stream_FileCacheImageOutputStream;
};

// Vtype
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_FileCacheImageOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_refs {
	struct _jc_java_io_OutputStream$object	*stream;
	struct _jc_java_io_File$object	*cacheDir;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$refs {
    _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_refs	javax_imageio_stream_FileCacheImageOutputStream;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_refs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_FileCacheImageOutputStream$sub_nonrefs	javax_imageio_stream_FileCacheImageOutputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_FileCacheImageOutputStream$object {
	_jc_javax_imageio_stream_FileCacheImageOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_FileCacheImageOutputStream$vtype	*vtype;
	_jc_javax_imageio_stream_FileCacheImageOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_FileCacheImageOutputStream$vtype _jc_javax_imageio_stream_FileCacheImageOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_FileCacheImageOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_FileCacheImageOutputStream$class_object;

#endif	/* _JC_javax_imageio_stream_FileCacheImageOutputStream_H_ */
